from aomaker.extension.recording.recording import Record


addons = [Record('baba.yaml', filter_str='console.qingcloud.com',
save_response=True, save_headers=False)]
    